%global year 2014
%global month 04


Name:           moarvm
Version:        0.%{year}.%{month}
Release:        5%{?dist}
Summary:        Short for "Metamodel On A Runtime", MoarVM is a virtual machine as a backend for NQP and then Rakudo Perl 6 at the top.

License:        Artistic 2.0
Group:          Development/Libraries
URL:            http://moarvm.org
Source0:        http://moarvm.org/releases/MoarVM-%{year}.%{month}.tar.gz

BuildRequires:  readline-devel libtommath-devel sha-devel libuv-devel
%if 0%{?fedora} > 20
BuildRequires:  libatomic_ops-devel >= 7.4
%endif
BuildRequires:  perl(Pod::Usage)



%description
Short for "Metamodel On A Runtime", MoarVM is a virtual machine built
especially for Rakudo Perl 6 and the NQP Compiler Toolchain. MoarVM is a 
backend for NQP.
MoarVM already stands out amongst the various Rakudo and NQP compilation
targets by typically:

    Running the Perl 6 specification test suite fastest
    Having the lowest memory usage
    Having the best startup time
    Being fastest to build both NQP and Rakudo - and thus in theory your
        Perl 6 and NQP programs too!


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}


%description devel
This package contains header files for developing applications that use
%{name} (Metamodel On A Runtime).



%prep
%setup -q -n MoarVM-%{year}.%{month}


%build
# modify Configure.pl so that the Fedora specific flags for cflags and ldflags
# will be written to the Makefile
sed -i -e "/^\$config{cflags}/ s#.*#\$config{cflags} = \"$RPM_OPT_FLAGS -fPIC\";#" Configure.pl
sed -i -e "/^\$config{ldflags}/ s#.*#\$config{ldflags} = \"%{__global_ldflags}\";#" Configure.pl

# make sure to not bundle this
rm -r 3rdparty/sha1 3rdparty/linenoise 3rdparty/msinttypes
%if 0%{?fedora} > 20
rm -r 3rdparty/libatomic_ops
%endif
#
# The upstream libtommath doesn't have the conversion from and to
# float/double that MoarVM needs. bn_mp_(get|set)_long.c are extentions of the
# origin libtommath source. The header files are needed to build.
rm `find 3rdparty/libtommath -type f ! -name '*long.c' -a ! -name '*.h'`

%{__perl} Configure.pl --prefix=%{_usr} --has-libtommath --use-readline \
                       --has-sha --has-libuv --has-libatomic_ops
sed -i -e '/libmoar.so.*lib$/ s#lib$#%{_lib}#' Makefile

make %{?_smp_mflags}


%install

# Create .../usr/lib64 directory at 64-bit architecture
[ %{_lib} == lib ] || mkdir -p $RPM_BUILD_ROOT%{_libdir}

%make_install

# Force permissions on shared versioned libs so they get stripped
# and will provided.
chmod 755 $RPM_BUILD_ROOT%{_libdir}/libmoar.so


%files
%doc LICENSE CREDITS docs
%{_bindir}/moar

%{_prefix}/lib/MAST
%{_libdir}/libmoar.so


%files devel
%{_includedir}/dyncall
%{_includedir}/moar
%{_includedir}/tinymt

%exclude %{_includedir}/linenoise
%exclude %{_includedir}/libtommath
%exclude %{_includedir}/sha1
%exclude %{_includedir}/libuv
%exclude %{_includedir}/msinttypes
%exclude %{_includedir}/libatomic_ops



%changelog
* Fri Aug 29 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.04-5
- remove of libtommath 3rdparty source files
- remove of libatomic_ops only if fedora > 20

* Fri Aug 22 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.04-4
- add 'BuildRequires: libatomic_ops-devel >= 7.4'
- first remove of 3rdparty source files

* Wed May 07 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.04-3
- modify Configure.pl so that the Fedora specific flags for cflags and ldflags
  will be written to the Makefile
- make lib64 directory creation more general

* Wed Apr 30 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.04-2
- add optimize flag to Configure.pl
- add CFLAGS and LDFLAGS to make
- change summary tag

* Sat Apr 26 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.04-1
- update to 2014.04
- remove patches that are included in upstream
- add BuildRequires perl(Pod::Usage)

* Mon Mar 31 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.03-2
- add patch to have more configuration flags
- call Confiugre.pl with has-libatomic_ops

* Wed Mar 26 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.03-1
- update to 2014.03
- call Configure.pl with has-sha and add BuildRequires sha-devel
- call Configure.pl with has-libuv and add BuildRequires libuv-devel
- exclude libuv and sha1 header file
- exclude header files for Microsoft Visual Studio (msinittypes)

* Mon Mar 17 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.02-3
- call Configure.pl with use-readline flag
- add BuildRequires readline-devel and libtommath-devel
- exclude linenoise and libtommath header file
- add patch to link with libtommath from the system and use it as a flag

* Fri Mar 14 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.02-2
- improve devel package tags
- description is no longer than 80 chars per line any more
- RPM_BUILD_ROOT cleanup is removed

* Sat Feb 22 2014 Gerd Pokorra <gp@zimt.uni-siegen.de> 0.2014.02-1
- create initial spec file from the template 'rpmdev-newspec moarvm' 
- add changing permission of libmoar.so
- add Group tag
- add devel-subpackage
